#
# spec file for package plplot
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} <= 1320
%define lua_version 5.2
%else
%define lua_version 5.3
%endif

%if 0%{?suse_version} > 1320 || (0%{?is_opensuse} && 0%{?sle_version}==120200)
%define tk_enabled 0
%else
%define tk_enabled 1
%endif

%if 0%{?suse_version} != 1315 || (0%{?is_opensuse} && 0%{?sle_version}==120200)
%define octave_enabled 1
%else
%define octave_enabled 0
%endif

%define X_display ":98"

Name:           plplot
Version:        5.11.1
Release:        4.2
Summary:        Cross-platform software package for creating scientific plots
License:        LGPL-2.1+
Group:          Productivity/Scientific/Other
Url:            http://plplot.sourceforge.net/
Source0:        http://download.sf.net/plplot/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM plplot-5.9.9-ada-pic.patch idoenmez@suse.de -- Compile Ada code with -fPIC
Patch1:         plplot-5.9.9-ada-pic.patch
# PATCH-FIX-UPSTREAM plplot-cmake36-pkg_check_pkgconfig_macro.patch badshah400@gmail.com -- Fix plplot's defined pkg_check_pkgconfig macro to work with cmake >= 3.6; patch sent upstream
Patch2:         plplot-cmake36-pkg_check_pkgconfig_macro.patch
BuildRequires:  cmake >= 3.0.2
BuildRequires:  fdupes
BuildRequires:  freefont
BuildRequires:  gcc-ada
BuildRequires:  gcc-fortran
BuildRequires:  itcl-devel
BuildRequires:  itk
BuildRequires:  java-devel
BuildRequires:  lapack-devel
BuildRequires:  libgcj-devel
BuildRequires:  libqt4-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  ocaml
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  python-numpy-devel
BuildRequires:  python-qt4-devel
BuildRequires:  swig
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangoft2)
# Required for enabling tk driverand in the %%check section, currently disabled
BuildRequires:  xorg-x11-server
BuildRequires:  perl(XML::DOM)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gnome-python-2.0)
BuildRequires:  pkgconfig(libgnomeprintui-2.2)
BuildRequires:  pkgconfig(libgnomeui-2.0)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(pygtk-2.0)
%if 0%{?suse_version} >= 1310
BuildRequires:  pkgconfig(lasi)
%endif
BuildRequires:  hdf5-devel
BuildRequires:  octave-devel
%if 0%{?suse_version} >= 1320
BuildRequires:  wxWidgets-devel >= 3
%else
BuildRequires:  wxWidgets-devel
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
%endif

Requires:       libtool
Requires:       python-base = %{py_ver}
Requires:       python-numpy
Recommends:     %{name}-doc = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): /sbin/ldconfig

%description
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

A variety of output file devices such as Postscript, png, jpeg, LaTeX
and others, as well as interactive devices such as xwin, tk, xterm and
Tektronics devices are supported. New devices can be easily added by
writing a small number of device dependent routines.

There are almost 2000 characters in the extended character set. This
includes four different fonts, the Greek alphabet and a host of
mathematical, musical, and other symbols. Some devices supports its own
way of dealing with text, such as the Postscript and LaTeX drivers, or
the png and jpeg drivers that uses the Freetype library.

This package provides the shared libraries for PLplot.

%package devel

Summary:        Files for development with PLplot
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       gcc-c++
Requires:       pkgconfig
Requires:       pkgconfig(freetype2)

%description devel
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the files necessary for development with PLplot
in C/C++.

%package doc

Summary:        Documentation for PLplot and its bindings
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the documentation for PLplot and its associated
modules.

%package ada
Summary:        Shared libraries for PLplot's Ada bindings
Group:          System/Libraries
Requires:       %{name} = %{version}

%description ada
A variety of output file devices such as Postscript, png, jpeg, LaTeX
and others, as well as interactive devices such as xwin, tk, xterm and
Tektronics devices are supported. New devices can be easily added by
writing a small number of device dependent routines.

There are almost 2000 characters in the extended character set. This
includes four different fonts, the Greek alphabet and a host of
mathematical, musical, and other symbols. Some devices supports its own
way of dealing with text, such as the Postscript and LaTeX drivers, or
the png and jpeg drivers that uses the Freetype library.

This package provides the shared libraries necessary for using PLplot
with Ada.

%package ada-devel

Summary:        Ada bindings for development with PLplot
Group:          Development/Languages/Other
Requires:       %{name} = %{version}
Requires:       %{name}-ada = %{version}
Requires:       %{name}-devel = %{version}
Requires:       gcc-ada
Requires:       pkgconfig

%description ada-devel
A variety of output file devices such as Postscript, png, jpeg, LaTeX
and others, as well as interactive devices such as xwin, tk, xterm and
Tektronics devices are supported. New devices can be easily added by
writing a small number of device dependent routines.

There are almost 2000 characters in the extended character set. This
includes four different fonts, the Greek alphabet and a host of
mathematical, musical, and other symbols. Some devices supports its own
way of dealing with text, such as the Postscript and LaTeX drivers, or
the png and jpeg drivers that uses the Freetype library.

This package provides the files necessary for using PLplot in Ada.

%package fortran
Summary:        Shared libraries for PLplot's Fortran bindings
Group:          System/Libraries
Requires:       %{name} = %{version}

%description fortran
A variety of output file devices such as Postscript, png, jpeg, LaTeX
and others, as well as interactive devices such as xwin, tk, xterm and
Tektronics devices are supported. New devices can be easily added by
writing a small number of device dependent routines.

There are almost 2000 characters in the extended character set. This
includes four different fonts, the Greek alphabet and a host of
mathematical, musical, and other symbols. Some devices supports its own
way of dealing with text, such as the Postscript and LaTeX drivers, or
the png and jpeg drivers that uses the Freetype library.

This package provides the shared libraries necessary for using PLplot
with Fortran.

%package fortran-devel

Summary:        Fortran bindings for development with PLplot
Group:          Development/Languages/Fortran
Requires:       %{name} = %{version}
Requires:       %{name}-devel = %{version}
Requires:       %{name}-fortran = %{version}
Requires:       gcc-fortran
Requires:       pkgconfig

%description fortran-devel
A variety of output file devices such as Postscript, png, jpeg, LaTeX
and others, as well as interactive devices such as xwin, tk, xterm and
Tektronics devices are supported. New devices can be easily added by
writing a small number of device dependent routines.

There are almost 2000 characters in the extended character set. This
includes four different fonts, the Greek alphabet and a host of
mathematical, musical, and other symbols. Some devices supports its own
way of dealing with text, such as the Postscript and LaTeX drivers, or
the png and jpeg drivers that uses the Freetype library.

This package provides the files necessary for using PLplot in Fortran.

%package java

Summary:        PLplot functions for scientific plotting with Java
Group:          Productivity/Scientific/Other
Requires:       %{name} = %{version}
Requires:       java

%description java
A variety of output file devices such as Postscript, png, jpeg, LaTeX
and others, as well as interactive devices such as xwin, tk, xterm and
Tektronics devices are supported. New devices can be easily added by
writing a small number of device dependent routines.

There are almost 2000 characters in the extended character set. This
includes four different fonts, the Greek alphabet and a host of
mathematical, musical, and other symbols. Some devices supports its own
way of dealing with text, such as the Postscript and LaTeX drivers, or
the png and jpeg drivers that uses the Freetype library.

This package provides the PLplot functions required for scientific
plotting with Java.

%package lua

Summary:        PLplot functions for scientific plotting with Lua
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       lua

%description lua
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the PLplot functions required for scientific
plotting with Lua.

%package octave

Summary:        PLplot functions for scientific plotting with Octave
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       octave

%description octave
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the PLplot functions required for scientific
plotting with Octave.

%package python-qt

Summary:        PLplot functions for scientific plotting with python-qt4
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python-base = %{py_ver}
Requires:       python-qt4

%description python-qt
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the PLplot functions required for scientific
plotting with python-qt.

%package qt
Summary:        PLplot functions for scientific plotting with qt
Group:          System/Libraries
Requires:       %{name} = %{version}

%description qt
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the PLplot functions required for scientific
plotting with Qt.

%package qt-devel

Summary:        PLplot functions for scientific plotting with qt
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       %{name}-devel = %{version}
Requires:       %{name}-qt = %{version}
Requires:       libqt4-devel
Requires:       pkgconfig

%description qt-devel
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the development files for using PLplot
with Qt.

%package tcltk
Summary:        PLplot functions for scientific plotting with Tk
Group:          System/Libraries
Requires:       %{name} = %{version}

%description tcltk
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the PLplot functions required for scientific
plotting with Tk.

%package tcltk-devel

Summary:        PLplot functions for scientific plotting with python-qt4
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       %{name}-devel = %{version}
Requires:       %{name}-tcltk = %{version}
Requires:       itcl-devel
Requires:       itk
Requires:       pkgconfig
Requires:       python-base = %{py_ver}
Requires:       tcl-devel
Requires:       tk-devel

%description tcltk-devel
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the development files for using PLplot with Tk.

%package wxwidgets

Summary:        PLplot functions for scientific plotting with wxGTK
Group:          System/Libraries
Requires:       %{name} = %{version}

%description wxwidgets
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the PLplot functions required for scientific
plotting with wxGTK.

%package wxwidgets-devel

Summary:        PLplot bindings for development with wxGTK
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       %{name}-devel = %{version}
Requires:       %{name}-wxwidgets = %{version}
Requires:       pkgconfig
Requires:       wxWidgets-devel

%description wxwidgets-devel
PLplot is a library of functions that are useful for making scientific
plots.

PLplot can be used from within compiled languages such as C, C++,
FORTRAN and Java, and interactively from interpreted languages such as
Octave, Python, Perl and Tcl.

The PLplot library can be used to create standard x-y plots, semilog
plots, log-log plots, contour plots, 3D surface plots, mesh plots, bar
charts and pie charts. Multiple graphs (of the same or different sizes)
may be placed on a single page with multiple lines in each graph.

This package provides the PLplot functions required for scientific
plotting with wxGTK.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

for file in NEWS README.release
do
  iconv -f ISO-8859-1 -t UTF-8 $file > ${file}.tmp
  touch -r $file ${file}.tmp
  mv ${file}.tmp $file
done

%build
%if 0%{?suse_version} >= 1310
export CFLAGS="%{optflags} -DUSE_INTERP_RESULT -fno-strict-aliasing"
%else
export CFLAGS="%{optflags} -fno-strict-aliasing"
%endif
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
export FFLAGS="%{optflags}"
mkdir builddir
pushd builddir

# X-server and $DISPLAY required to enable tk bindings
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
sleep 5
cmake \
        -DCMAKE_INSTALL_LIBDIR=%{_libdir} \\\
        -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \\\
        -DCMAKE_BUILD_TYPE:STRING=Release \\\
        -DPL_FREETYPE_FONT_PATH:PATH="%{_datadir}/fonts/truetype" \\\
        -DUSE_RPATH:BOOL=OFF \\\
        -DENABLE_ada:BOOL=ON \\\
%if 0%{?octave_enabled}
        -DENABLE_octave:BOOL=ON \\\
        -DTRY_OCTAVE4=ON \\\
%else
        -DENABLE_octave:BOOL=OFF \\\
%endif
        -DENABLE_d:BOOL=ON \\\
        -DENABLE_itcl:BOOL=ON \\\
%if 0%{?tk_enabled} > 1320
        -DENABLE_itk:BOOL=OFF \\\
        -DENABLE_tk:BOOL=OFF \\\
%else
        -DENABLE_itk:BOOL=ON \\\
        -DENABLE_tk:BOOL=ON \\\
%endif
        -DENABLE_ocaml:BOOL=ON \\\
        -DPLD_aqt:BOOL=ON \\\
        -DPLD_conex:BOOL=ON \\\
        -DPLD_plmeta:BOOL=OFF \\\
        -DPLD_mskermit:BOOL=ON \\\
        -DPLD_svg:BOOL=ON \\\
        -DPLD_tek4010:BOOL=ON \\\
        -DPLD_tek4010f:BOOL=ON \\\
        -DPLD_tek4107:BOOL=ON \\\
        -DPLD_tek4107f:BOOL=ON \\\
        -DPLD_versaterm:BOOL=ON \\\
        -DPLD_vlt:BOOL=ON \\\
        -DPLD_xterm:BOOL=ON \\\
        -DPLD_wxwidgets:BOOL=ON \\\
        -DBUILD_DOC:BOOL=OFF \\\
        -DPREBUILT_DOC:BOOL=ON \\\
        -DJAVAWRAPPER_DIR:PATH="%{_libdir}/plplot%{version}" \\\
        -DBUILD_TEST:BOOL=OFF  \\\
        -DENABLE_lua:BOOL=ON \\\
        ..

make %{?_smp_mflags}
popd

%install
pushd builddir
%make_install DESTDIR=%{buildroot}
popd

# Fix up tclIndex files so they are the same on all builds
for file in %{buildroot}%{_datadir}/plplot%{version}/examples/*/tclIndex
do
   grep '^[# ]' ${file} > tclIndex.hd
   grep -v '^[# ]' ${file} | sort > tclIndex
   cat tclIndex.hd tclIndex > ${file}
done
rm -rf %{buildroot}%{_datadir}/plplot%{version}/examples/cmake/modules/Platform

#Remove unnecessary examples that trigger build errors or warnings
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/cmake/modules/export_plplot-release.cmake
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/test_octave_interactive.sh
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/tk/*.in
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/tcl/*.in
rm -f %{buildroot}%{_datadir}/%{name}%{version}/examples/tk/tk01

#Remove cmake files for the examples since they don't work anyway due to presence of rpath
rm -f %{buildroot}%{_datadir}/plplot%{version}/examples/CMakeLists.txt
rm -fr %{buildroot}%{_datadir}/plplot%{version}/examples/cmake

#Move doc files to appropriate location
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{_docdir}/%{name}-doc

%if %{tk_enabled}
#Grant executable permissions to example tk binaries with valid shebang
chmod +x %{buildroot}%{_datadir}/%{name}%{version}/examples/tk/tk03
%endif

#Remove a fortran static library
rm -fr %{buildroot}%{_libdir}/libplf95*.a

%fdupes %{buildroot}%{_datadir}/

## Disable check section for now (until octave tests are fixed)
#%%check
#pushd builddir
## octave tests require Xserver display
#export DISPLAY=%%{X_display}
#Xvfb %%{X_display} >& Xvfb.log &
#sleep 5
#export octaveopts=--no-window-system
#make %%{?_smp_mflags} test_diff_psc
#popd

%post
/sbin/ldconfig
/sbin/install-info %{_infodir}/plplotdoc.info %{_infodir}/dir

%preun
/sbin/install-info --delete %{_infodir}/plplotdoc.info %{_infodir}/dir

%postun -p /sbin/ldconfig

%post -n plplot-ada -p /sbin/ldconfig

%postun -n plplot-ada -p /sbin/ldconfig

%post -n plplot-fortran -p /sbin/ldconfig

%postun -n plplot-fortran -p /sbin/ldconfig

%post -n plplot-tcltk -p /sbin/ldconfig

%postun -n plplot-tcltk -p /sbin/ldconfig

%post -n plplot-qt -p /sbin/ldconfig

%postun -n plplot-qt -p /sbin/ldconfig

%post -n plplot-wxwidgets -p /sbin/ldconfig

%postun -n plplot-wxwidgets -p /sbin/ldconfig

%files doc
%defattr(-,root,root)
%dir %{_docdir}/%{name}-doc
%{_docdir}/%{name}-doc/*

%files
%defattr(-,root,root)
%doc AUTHORS COPYING.LIB Copyright FAQ README README.release
%{_bindir}/pltek
%{_infodir}/plplotdoc.info*
%{_mandir}/man1/pltek.1.gz
# PLMETA DRIVER DISABLED
#%%{_bindir}/plm2gif
#%%{_bindir}/plpr
#%%{_bindir}/plrender
#%%{_mandir}/man1/plm2gif.1.gz
#%%{_mandir}/man1/plpr.1.gz
#%%{_mandir}/man1/plrender.1.gz
%dir %{_datadir}/plplot%{version}
%{_datadir}/plplot%{version}/*.fnt
%{_datadir}/plplot%{version}/*.map
%{_datadir}/plplot%{version}/*.pal
%dir %{_datadir}/plplot%{version}/examples
%{_datadir}/plplot%{version}/examples/lena.pgm
%{_datadir}/plplot%{version}/examples/plplot-test.sh
%{_datadir}/plplot%{version}/examples/plplot-test-interactive.sh
%{_datadir}/plplot%{version}/examples/python/
%{_datadir}/plplot%{version}/examples/test_python.sh
%{python_sitearch}/_plplotcmodule.so
%{python_sitearch}/plplot.py*
%{python_sitearch}/plplotc.py*
%if %{tk_enabled}
%{python_sitearch}/Plframe.py*
%{python_sitearch}/TclSup.py*
%endif
%{_libdir}/libcsirocsa.so.*
%{_libdir}/libplplotcxx.so.*
%{_libdir}/libplplot.so.*
%{_libdir}/libqsastime.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/plplot/
%{_libdir}/libcsirocsa.so
%{_libdir}/libplplotcxx.so
%{_libdir}/libplplot.so
%{_libdir}/libqsastime.so
%{_libdir}/pkgconfig/plplot.pc
%{_libdir}/pkgconfig/plplot-c++.pc
%dir %{_libdir}/cmake/plplot
%{_libdir}/cmake/plplot/export_plplot-release.cmake
%{_libdir}/cmake/plplot/export_plplot.cmake
%{_libdir}/cmake/plplot/plplotConfig.cmake
%dir %{_libdir}/plplot%{version}
%dir %{_libdir}/plplot%{version}/drivers
%{_libdir}/plplot%{version}/drivers/cairo.driver_info
%{_libdir}/plplot%{version}/drivers/cairo.so
%{_libdir}/plplot%{version}/drivers/mem.driver_info
%{_libdir}/plplot%{version}/drivers/mem.so
%if %{tk_enabled}
%{_libdir}/plplot%{version}/drivers/ntk.driver_info
%{_libdir}/plplot%{version}/drivers/ntk.so
%endif
%{_libdir}/plplot%{version}/drivers/null.driver_info
%{_libdir}/plplot%{version}/drivers/null.so
%{_libdir}/plplot%{version}/drivers/ps.so
%{_libdir}/plplot%{version}/drivers/ps.driver_info
%if 0%{?suse_version} >= 1310
%{_libdir}/plplot%{version}/drivers/psttf.driver_info
%{_libdir}/plplot%{version}/drivers/psttf.so
%endif
%{_libdir}/plplot%{version}/drivers/svg.driver_info
%{_libdir}/plplot%{version}/drivers/svg.so
%{_libdir}/plplot%{version}/drivers/xfig.driver_info
%{_libdir}/plplot%{version}/drivers/xfig.so
%{_libdir}/plplot%{version}/drivers/xwin.driver_info
%{_libdir}/plplot%{version}/drivers/xwin.so
%{_datadir}/plplot%{version}/examples/c/
%{_datadir}/plplot%{version}/examples/c++/
%{_datadir}/plplot%{version}/examples/Makefile
%{_datadir}/plplot%{version}/examples/test_c.sh
%{_datadir}/plplot%{version}/examples/test_c_interactive.sh
%{_datadir}/plplot%{version}/examples/test_cxx.sh
%{_datadir}/plplot%{version}/examples/test_diff.sh
%{_mandir}/man3/pl*.3*
# PLMETA DRIVER DISABLED
#%%{_datadir}/plplot%%{version}/examples/test_plrender.sh
#%%{_libdir}/plplot%%{version}/drivers/plmeta.driver_info
#%%{_libdir}/plplot%%{version}/drivers/plmeta.so

%files ada
%defattr(-,root,root)
%{_libdir}/libplplotada.so.*

%files ada-devel
%defattr(-,root,root)
%dir %{_libdir}/ada
%dir %{_libdir}/ada/adalib
%dir %{_datadir}/ada
%dir %{_datadir}/ada/adainclude
%{_libdir}/libplplotada.so
%{_libdir}/ada/adalib/plplotada/
%{_libdir}/pkgconfig/plplot-ada.pc
%{_datadir}/ada/adainclude/plplotada/
%{_datadir}/plplot%{version}/examples/ada/
%{_datadir}/plplot%{version}/examples/test_ada.sh

%files fortran
%defattr(-,root,root)
%{_libdir}/libplplotf95c.so.*
%{_libdir}/libplplotf95.so.*

%files fortran-devel
%defattr(-,root,root)
%dir %{_libdir}/fortran
%dir %{_libdir}/fortran/modules
%{_libdir}/fortran/modules/plplot/
%{_libdir}/libplplotf95c.so
%{_libdir}/libplplotf95.so
%{_libdir}/pkgconfig/plplot-f95.pc
%{_datadir}/plplot%{version}/examples/f95/
%{_datadir}/plplot%{version}/examples/test_f95.sh

%files lua
%defattr(-,root,root)
%{_libdir}/lua/%{lua_version}/plplot/
%{_datadir}/plplot%{version}/examples/lua/
%{_datadir}/plplot%{version}/examples/test_lua.sh

%files java
%defattr(-,root,root)
%{_libdir}/plplot%{version}/plplotjavac_wrap.so
%{_datadir}/java/plplot.jar
%{_datadir}/plplot%{version}/examples/java/
%{_datadir}/plplot%{version}/examples/test_java.sh

%files tcltk
%defattr(-,root,root)
%{_libdir}/libplplottcltk*.so.*
%{_libdir}/libtclmatrix.so.*

%files tcltk-devel
%defattr(-,root,root)
%{_bindir}/pltcl
%{_libdir}/libplplottcltk*.so
%{_libdir}/libtclmatrix.so
%{_libdir}/pkgconfig/plplot-tcl*.pc
%{_datadir}/plplot%{version}/examples/test_tcl.sh
%{_datadir}/plplot%{version}/examples/tcl/
%{_datadir}/plplot%{version}/pkgIndex.tcl
%{_datadir}/plplot%{version}/tcl/
%{_mandir}/man1/plserver.1.gz
%{_mandir}/man1/pltcl.1.gz
%{python_sitearch}/plplot_widgetmodule.so
%if %{tk_enabled}
%{_bindir}/plserver
%{_datadir}/plplot%{version}/examples/tk/
%{_libdir}/plplot%{version}/drivers/tk.driver_info
%{_libdir}/plplot%{version}/drivers/tk.so
%{_libdir}/plplot%{version}/drivers/tkwin.driver_info
%{_libdir}/plplot%{version}/drivers/tkwin.so
%endif

%files wxwidgets
%defattr(-,root,root)
%{_bindir}/wxPLViewer
%{_libdir}/libplplotwxwidgets.so.*

%files wxwidgets-devel
%defattr(-,root,root)
%{_libdir}/libplplotwxwidgets.so
%{_libdir}/pkgconfig/plplot-wxwidgets.pc
%{_libdir}/plplot%{version}/drivers/wxwidgets.driver_info
%{_libdir}/plplot%{version}/drivers/wxwidgets.so

%files python-qt
%defattr(-,root,root)
%{python_sitearch}/plplot_pyqt4.so

%files qt
%defattr(-,root,root)
%{_libdir}/libplplotqt.so.*

%files qt-devel
%defattr(-,root,root)
%{_libdir}/libplplotqt.so
%{_libdir}/pkgconfig/plplot-qt.pc
%{_libdir}/plplot%{version}/drivers/qt.driver_info
%{_libdir}/plplot%{version}/drivers/qt.so

%if 0%{?octave_enabled} 
%files octave
%defattr(-,root,root)
%{_datadir}/%{name}_octave/
%{_datadir}/octave/site/m/PLplot/
%{_libdir}/octave/site/oct/*/plplot_octave.oct
%{_datadir}/plplot%{version}/examples/octave/
%{_datadir}/plplot%{version}/examples/lena.img
%{_datadir}/plplot%{version}/examples/test_octave.sh
%endif

%changelog
* Mon Aug  8 2016 badshah400@gmail.com
- Define macro "octave_enabled" to consistently check when
  octave bindings are disabled (only for openSUSE:Leap:42.1).
- Disable tk bindings also for openSUSE:Leap:42.2 -- it does not
  build because of Xvfb crash (boo#992429).
* Sat Aug  6 2016 badshah400@gmail.com
- Enable octave bindings for openSUSE >= 13.2; builds just fine
  now.
* Sat Aug  6 2016 badshah400@gmail.com
- Add plplot-cmake36-pkg_check_pkgconfig_macro.patch to fix
  plplot's defined pkg_check_pkgconfig macro to work with
  cmake >= 3.6; patch sent upstream.
* Tue Apr 12 2016 normand@linux.vnet.ibm.com
- disable Tk bindings in Factory need more change in spec
  to avoid ppc64 build error.
* Wed Mar 30 2016 badshah400@gmail.com
- Disable octave bindings for openSUSE > 13.2 temporarily until
  related build failures are sorted out.
- Tk in Factory is not compatible with plplot apparently, turn
  off tk bindings until fix found.
- Bump required cmake version to 3.0.2, has been required since
  v5.11.1.
- Some rpmlint warning cleanups from using macros in comments.
* Wed Nov 25 2015 p.drouand@gmail.com
- Remove pkgconfig(libagg) requirement; the package doesn't build
  against it anyway
* Tue Aug 18 2015 badshah400@gmail.com
- Disable octave bindings for openSUSE:42 as it doesn't have
  a recent enough swig (>= 3.0) to support this.
* Thu Aug 13 2015 badshah400@gmail.com
- Update to version 5.11.1:
  + Bug fixes.
  + Improve traditional build linking for nondynamic device
    drivers case.
  + Comply with a NEW value for the CMake CMP0022, CMP0023 and
    CMP0026 policies.
  + Plot labels as date / time are now available for 3D plots.
  + Comprehensive testing script improvements.
  + Build system and file cleanup concerning retired devices.
  + Many improvements and bug fixes for the new wxwidgets device.
  + Substantially improved results for comprehensive testing of
    PLplot on the Cygwin platform.
  + Initial success of comprehensive testing of PLplot on the
    MSYS2 platform.
- Drop plplot-swig-3.0.6.patch: incorporated upstream (use
  - DTRY_OCTAVE4=ON option to build against octave 4.0 if
  available).
- Disable plmeta driver: fails to build.
- Disable building tests: we can't seem to get make check
  working anyway.
* Sun Jul 26 2015 badshah400@gmail.com
- Add plplot-swig-3.0.6.patch to fix builds against swig 3.0.6;
  patch taken from Fedora and accepted upstream.
- Enable octave bindings back, patch against swig to fix its
  octave4 bindings has already entered develprojects and Factory.
- Define %%{lua_version} to be 5.3 for openSUSE > 13.2 (Factory
  has lua 5.3.x now).
- Drop conditionals for EOL openSUSE versions.
* Tue Jun  9 2015 badshah400@gmail.com
- Disable octave bindings for now, since build fails with
  octave >= 4.0 (now in science and TW).
* Mon Apr 13 2015 badshah400@gmail.com
- Update to version 5.11.0:
  + Long list of changes, incl. backward incompatible changes
    over version 5.10.0; see
    /usr/share/doc/packages/plplot/README.release for a full
    list.
- Adapt file-list to dropping of the 'd' suffix for shared libs.
- Drop 0001-fix_for_cmake_3.1.patch: incorporated upstream.
- Enable plmeta driver, it is now actively maintained by
  upstream again.
- Add new binaries and man files installed by upstream.
* Sun Mar 15 2015 jengelh@inai.de
- Remove redundant ldconfig requires
- Build with wxWidgets 3
* Sat Jan 31 2015 sfalken@opensuse.org
- Added 0001-fix_for_cmake_3.1.patch to fix building on cmake>3.0
  http://sourceforge.net/p/plplot/plplot/ci/772223c638ecf5dc740c9f3dd7a6883c6d2c83d2/
* Tue Sep 23 2014 sfalken@opensuse.org
- Added -fno-strict-aliasing to CFLAGS and CXXFLAGS to clear warning:
  [  138s] I: Program is likely to break with new gcc. Try -fno-strict-aliasing.
  [  138s] W: plplot strict-aliasing-punning /home/abuild/rpmbuild/BUILD/plplot-5.10.0/builddir/bindings/java/plplotjavacJAVA_wrap.c:2441, 2454, 2467, 2480, 2493, 2506, 2519, 2532, 2545, 2558, 2571, 2597, 2610, 2623, 2636, 2649, 2662, 2675, 2688, 2701, 2714, 2727, 2740, 2753, 2767, 2777, 10385
* Mon Jul 21 2014 badshah400@gmail.com
- Re-enable the tcl-tk bindings for factory as the problem seems
  to have fixed itself (likely due to tk update).
* Sun Jun 29 2014 badshah400@gmail.com
- Disable tcl-tk bindings for factory until we manage to fix what
  is going wrong.
* Thu Feb 13 2014 badshah400@gmail.com
- Update to version 5.10.0:
  + Update the parts of the build system that find Tcl-related
    software
  + Update api.xml to be consistent with our public API defined by
    plplot.h
- Packaging changes:
  + Drop plplot-avoid-config_h-nameclash.patch: incorporated
    upstream
  + Add BuildRequires: xorg-x11-server as %%configure requires
    x-server to find and enable the tk bindings now
  + Implement a %%check section to carry out build testing, but
    disable actual testing until octave tests are fixed
  + Also package the FAQ file as %%doc.
* Thu Jan 30 2014 badshah400@gmail.com
- Enable octave bindings (requires patched swig version from
  devel:tools:building)
- Add patch plplot-avoid-config_h-nameclash.patch to fix build
  errors when octave bindings are enabled for openSUSE > 13.1;
  patch taken from upstream svn.
* Thu Jan  2 2014 badshah400@gmail.com
-  Turn off octave bindings until bugs with octave >= 3.8.0 are
  fixed upstream.
* Mon Dec 23 2013 badshah400@gmail.com
- Update to version 5.9.11:
  + Change CMake variable NUMERIC_INCLUDE_PATH to
    NUMPY_INCLUDE_PATH
  - Overhaul of the build system and bindings for Tcl and friends
  - Substantial overhaul of the build system for the Qt components
- Packaging changes:
  - Drop patches:
  - plplot-lua-5_2.patch: incorporated upstream
  - plplot-tcl-import-usage.patch: incorporated upstream
  - A shared library file was added to the tcltk bindings, also
    package this appropriately (and its related devel files)
  - BuildRequires: pkgconfig(lasi) for openSUSE 13.1 and above,
    so that psttf driver can be built as well
  - The driver pstex is disabled as recommended by upstream
  - Remove conditionals solely necessitated by EOL versions of
    openSUSE.
* Wed Oct  2 2013 badshah400@gmail.com
- Update to version 5.9.10:
  + The format for map data used by plmap has changed
  + Python support for Numeric has been dropped
  + Backwards-incompatible API change to non-integer line widths
  + Improvements to the build system for the Cygwin case
  + The plcolorbar API has been finalized
  + Documentation of the new legend and color bar capabilities of
    PLplot
  + The D bindings and examples have been converted from the
    old version of D (D1) to the new version of D (D2)
  + The DocBook documentation for PLplot is now generated using
    modern XML/XSL backend tools for DocBook
  + Implement experimental build_projects sub-project
  + Implement extremely simple "00" example
  + Convert to using the Allura form of SourceForge software
  + Use NON_TRANSITIVE linking by default for the shared libraries
    case for all non-windows systems
  + Update f95 examples to take larger advantage of Fortran 95
    capabilities
  + Substantial additions to the doxygen documentation
- Packaging changes:
  + Turn ada bindings back on
  + Remove restriction on lua version used, since package now
    builds with lua version >= 5.2 as well
  + Turn off f77 bindings, as recommended by upstream
  + Drop patches that have been incorporated upstream:
  - plplot-multiarch.patch
  - plplot-gcc-ada46-libs.patch
  - plplot-strncat.patch
- Add plplot-lua-5_2.patch to replace usage of log10, deprecated
  in lua 5.2, in favour of log(,10) in some lua based examples.
* Tue Aug 20 2013 badshah400@gmail.com
- Pass "-DUSE_INTERP_RESULT" to CFLAGS for openSUSE >= 13.1 to fix
  build failures from usage of interp->result which is deprecated
  in Tcl 8.6
- In addition, use plplot-tcl-import-usage.patch to fix type
  inconsistency in Tcl_Import (for >= 13.1 only); re-enable
  building of tck/tk bindings for openSUSE 13.1.
* Tue Aug 20 2013 badshah400@gmail.com
- Disable tck/tk bindings completely for Factory to workaround
  build failures from usage of interp->result which is deprecated
  in Tcl 8.6.
* Sat Dec  8 2012 badshah400@gmail.com
- Disable ada bindings for Factory as they cause build errors.
* Mon Sep 17 2012 idonmez@suse.com
- Add plplot-5.9.9-ada-pic.patch to compile Ada code with -fPIC
* Tue May 29 2012 badshah400@gmail.com
- Enable octave bindings also for openSUSE 12.1; building octave
  bindings fail on openSUSE < 12.1 and have been turned off.
* Mon May 14 2012 badshah400@gmail.com
- Enable octave bindings for openSUSE > 12.1 since octave is now
  in factory. The octave bindings are packaged in a separate
  package called plplot-octave.
* Sun Apr 22 2012 dimstar@opensuse.org
- Extend plplot-gcc-ada46-libs.patch to include gnat-4.7 in plus.
* Sat Apr  7 2012 badshah400@gmail.com
- Update lapack buildrequires in keeping with lapack package
  naming changes in devel project; enables building on openSUSE
  12.1 and 11.4 again.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Feb 12 2012 badshah400@gmail.com
- Enable lua bindings for factory again, using BuildRequires:
  pkgconfig(lua) < 5.2.
* Thu Feb  9 2012 badshah400@gmail.com
- Disable lua bindings for factory, since build fails with
  lua > 5.1
* Sun Nov 20 2011 werner.ho@gmx.de
- dropped the qhull requirement from the spec-file
  I've not seen any need of it in the INSTALL/README files
* Tue Oct 18 2011 badshah400@gmail.com
- Update to version 5.9.9
  + Minor bug fixes for Windows platform
* Mon Oct  3 2011 dimstar@opensuse.org
- Fix typo in Patch tagline.
* Mon Aug  8 2011 badshah400@gmail.com
- Enable ada bindings
- Added plplot-gcc-ada46-libs.patch to enable compilation with
  gcc-ada = 4.6
* Mon Aug  1 2011 badshah400@gmail.com
- Update to version 5.9.8 (too many changes, see README.release
  file for changes)
* Sat Jul 16 2011 badshah400@gmail.com
- Configure spec file to allow outputs in jpeg, gif formats
* Sun May 29 2011 badshah400@gmail.com
- Added gcc-c++ dependency for plplot-devel
- Cleanup spec file and correct build dependencies to resolve
  build issues with openSUSE 11.3
* Sat May 28 2011 badshah400@gmail.com
- Rename (sub)packages and cleanup spec file
- Add rpmlintrc file to avoid false-positives
* Tue May 10 2011 badshah400@gmail.com
- Remove misbehaving cmake based examples altogether
* Mon May  9 2011 badshah400@gmail.com
- Initial package (version 5.9.7)
